misc

# XMLRésuméLibrary: User Guide

minor | Element Reference | month

## Name

misc — Miscellaneous remarks

## Synopsis

### Content Model

    (para+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `misc` element contains paragraphs of text that don't fit into any other top-level categories.

### Parents

`misc` may be contained in these elements: `resume`

## Examples

    <misc>
      <para>What can't be captured on a r&eacute;sum&eacute; is my sheer
        level of <emphasis>enthusiasm</emphasis> for not just cooking
        food, but dealing with people.  I'm told I make nearly every
        kitchen run more smoothly because I know how to manage and make
        people want to <emphasis>do their best</emphasis>.
      </para>
      <para>I'm listed in <citation>Who's Who in American
          Restaurants</citation> as well as <citation>La
          Rubach&ograve;n</citation>.
      </para>
    </misc>

minor | Element Reference | month